use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(User::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(User::Id).text().not_null().primary_key())
                    .col(
                        ColumnDef::new(User::Activated)
                            .boolean()
                            .not_null()
                            .default(false),
                    )
                    .col(ColumnDef::new(User::Username).text().not_null())
                    .col(ColumnDef::new(User::Email).text().not_null())
                    .col(ColumnDef::new(User::PasswordHash).text().not_null())
                    .col(ColumnDef::new(User::MfaKey).text())
                    .col(ColumnDef::new(User::DisplayName).text().not_null())
                    .col(ColumnDef::new(User::Summary).text().not_null().default(""))
                    .col(ColumnDef::new(User::Created).date_time().not_null())
                    .col(
                        ColumnDef::new(User::ManuallyApprovesFollowers)
                            .boolean()
                            .not_null()
                            .default(false),
                    )
                    .col(
                        ColumnDef::new(User::Discoverable)
                            .boolean()
                            .not_null()
                            .default(false),
                    )
                    .col(
                        ColumnDef::new(User::AlwaysMarkAsNsfw)
                            .boolean()
                            .not_null()
                            .default(false),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(User::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
pub enum User {
    Table,
    Id,
    Activated,
    Username,
    Email,
    PasswordHash,
    MfaKey,
    DisplayName,
    Summary,
    Created,
    ManuallyApprovesFollowers,
    Discoverable,
    AlwaysMarkAsNsfw,
}
