use crate::m20230619_221344_create_user::User;
use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(KeyPair::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(KeyPair::User)
                            .text()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(KeyPair::Public).string().not_null())
                    .col(ColumnDef::new(KeyPair::Private).string().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-user_id-keypair_user")
                            .from(KeyPair::Table, KeyPair::User)
                            .to(User::Table, User::Id),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(KeyPair::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
enum KeyPair {
    Table,
    User,
    Public,
    Private,
}
