use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Session::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(Session::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(Session::Token).string().not_null())
                    .col(ColumnDef::new(Session::User).string().not_null())
                    .col(ColumnDef::new(Session::Issued).date_time().not_null())
                    .col(ColumnDef::new(Session::Expiry).date_time().not_null())
                    .col(ColumnDef::new(Session::Device).string().not_null())
                    .col(ColumnDef::new(Session::Ip).inet().not_null())
                    .col(ColumnDef::new(Session::LastUsage).date_time())
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Session::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
enum Session {
    Table,
    Id,
    Token,
    User,
    Issued,
    Expiry,
    Device,
    Ip,
    LastUsage,
}
